      subroutine prfind(xlat,estozn,lprint,ilat,iloprf,ihiprf)
c
c***********************************************************************
c
c     prfind
c
c     september 2001 by charlie wellemeyer of ssai
c
c     purpose
c        compute table indices
c
c     method
c        tables contain 21 profiles. 3 equatorial, 8 mid latitude, and
c        10 are for high latitudes.
c
c     variables
c       name      type  i/o   description
c       ----      ----  ---   -----------
c      arguments
c       ilat      i*4    i    latitude index
c       estozn    r*8    i    ozone amount
c       iloprf    i*4    o    profile index for low  boundary n value
c       ihiprf    i*4    o    profile index for high boundary n value
c      internal
c       ilow      i*4         minimum profile index for low mid and high
c       ihigh     i*4         maximum profile index for low mid and high
c       lattab    i*4         profile index offsets for low mid and high
c
c***********************************************************************
c
      implicit none
c
      real xlat, estozn
      integer ilat,iloprf, ihiprf
      logical lprint(30)
      integer ihigh(3),ilow(3),lattab(3)
      data ilow/1,4,12/, ihigh /3,11,21/, lattab/-3,0,10/
c
c     -- set indices for profile selection
c
      iloprf = (estozn-25.)/50. + lattab(ilat)
      if (iloprf.ge.ihigh(ilat)) then
         iloprf = ihigh(ilat) - 1
      else if (iloprf.lt.ilow(ilat)) then
         iloprf = ilow(ilat)
      endif
      ihiprf = iloprf + 1
c
      if(lprint(14)) write (6,*) 'prfind:  xlat,estozn,ilat,
     1 lattab,iloprf,ihiprf = ',xlat,estozn,ilat,lattab(ilat),
     2 iloprf,ihiprf
c
      return
c
      end
